==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebForOfStateEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebForOfStateDetailDescriptionMetadata } from "./WebForOfStateDetailDescriptionMetadata";
import { WebForOfStateEventArgsDescription } from "./WebForOfStateEventArgsDescription";
/**
 * @hidden
 */
var WebForOfStateEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebForOfStateEventArgsDescriptionMetadata, _super);
    function WebForOfStateEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebForOfStateEventArgsDescriptionMetadata.b = function (a) {
        if (WebForOfStateEventArgsDescriptionMetadata.a == null) {
            WebForOfStateEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebForOfStateEventArgsDescriptionMetadata.c(WebForOfStateEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebForOfStateEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebForOfStateEventArgsDescriptionMetadata.a);
        WebForOfStateDetailDescriptionMetadata.d(a);
    };
    WebForOfStateEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ForOfStateEventArgs");
        a.item("Detail", "ExportedType:WebForOfStateDetail");
    };
    WebForOfStateEventArgsDescriptionMetadata.d = function (a) {
        WebForOfStateEventArgsDescriptionMetadata.b(a);
        a.ad("WebForOfStateEventArgs", function () { return new WebForOfStateEventArgsDescription(); });
        a.ac("WebForOfStateEventArgs", WebForOfStateEventArgsDescriptionMetadata.a);
    };
    WebForOfStateEventArgsDescriptionMetadata.$t = markType(WebForOfStateEventArgsDescriptionMetadata, 'WebForOfStateEventArgsDescriptionMetadata');
    WebForOfStateEventArgsDescriptionMetadata.a = null;
    return WebForOfStateEventArgsDescriptionMetadata;
}(Base));
export { WebForOfStateEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebForOfStateEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebForOfStateDetailDescriptionMetadata } from "./WebForOfStateDetailDescriptionMetadata";
import { WebForOfStateEventArgsDescription } from "./WebForOfStateEventArgsDescription";
/**
 * @hidden
 */
var WebForOfStateEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebForOfStateEventArgsDescriptionMetadata, _super);
    function WebForOfStateEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebForOfStateEventArgsDescriptionMetadata.b = function (a) {
        if (WebForOfStateEventArgsDescriptionMetadata.a == null) {
            WebForOfStateEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebForOfStateEventArgsDescriptionMetadata.c(WebForOfStateEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebForOfStateEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebForOfStateEventArgsDescriptionMetadata.a);
        WebForOfStateDetailDescriptionMetadata.d(a);
    };
    WebForOfStateEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ForOfStateEventArgs");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("Detail", "ExportedType:WebForOfStateDetail");
    };
    WebForOfStateEventArgsDescriptionMetadata.d = function (a) {
        WebForOfStateEventArgsDescriptionMetadata.b(a);
        a.ae("WebForOfStateEventArgs", function () { return new WebForOfStateEventArgsDescription(); });
        a.ad("WebForOfStateEventArgs", WebForOfStateEventArgsDescriptionMetadata.a);
    };
    WebForOfStateEventArgsDescriptionMetadata.$t = markType(WebForOfStateEventArgsDescriptionMetadata, 'WebForOfStateEventArgsDescriptionMetadata');
    WebForOfStateEventArgsDescriptionMetadata.a = null;
    return WebForOfStateEventArgsDescriptionMetadata;
}(Base));
export { WebForOfStateEventArgsDescriptionMetadata };
